import gspread
import matplotlib.pyplot as plt
import pandas as pd
from oauth2client.service_account import ServiceAccountCredentials
def gsheet(sheet_id, json_file , xaxis, yaxis):
    scope = ["https://spreadsheets.google.com/feeds","https://www.googleapis.com/auth/drive.file","https://www.googleapis.com/auth/drive"]
    credentials = ServiceAccountCredentials.from_json_keyfile_name(json_file, scope)
    docid = sheet_id
    client = gspread.authorize(credentials)
    spreadsheet = client.open_by_key(docid)
    sheet = spreadsheet.sheet1
    list_of_gspread = sheet.get_all_records()
    data = pd.DataFrame.from_dict(list_of_gspread)
    fig, ax = plt.subplots()
    ax.plot(data[xaxis], color='black', label='Average sales')
    #ax.yaxis.set_major_locator(data.timestamp)
    ax.legend()
    ax.set_xlabel(yaxis)
    plt.savefig('saved_figure.png')
    plt.show()




from setuptools import setup

def readme():
    with open('README.md') as f:
        README = f.read()
    return README


setup(
    name="gsheet_access",
    version="1.1.1",
    description="A Python package to read gsheet  from google drive using gsheet id and plot and save between two numerical axis.",
    long_description=readme(),
    long_description_content_type="text/markdown",
    author="Amreesh kumar",
    author_email="starkk786@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    packages=["gsheet_access"],
    include_package_data=True,
    install_requires=["pandas","numpy","gsheet","oauthclient","matplotlib"]
)